.. _references:

Citations & References
======================

The bibtex entries for **PyAutoFit** and its affiliated software packages can be found
`here <https://github.com/rhayes777/PyAutoFit/blob/master/citations.bib>`_, with example text for citing **PyAutoFit**
in `.tex format here <https://github.com/rhayes777/PyAutoFit/blob/master/citation.tex>`_ format here and
`.md format here <https://github.com/rhayes777/PyAutoFit/blob/master/citations.md>`_. As shown in the examples, we
would greatly appreciate it if you mention **PyAutoFit** by name and include a link to our GitHub page!

The **PyAutoFit** publication has been submitted to the Journal of Open Source Software and its entry in the above .bib
file is a placeholder linking to the GitHub.